#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
                 #                      >>>>>>>>>>>>>>>>>>>>>>>>>>>>>
# Debianize (initial)
CD ${SOURCE_PATH}
cd ${SOURCE_PATH}
L "debmake"
