#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                       =============
# @ ${BASE_PATH}

sed -n -e 's/^Standards-Version: *\(.*\)$/\1/p' debhello-0.0/debian/control
