#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                       >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
CD ${SOURCE_PATH}
cd ${SOURCE_PATH}
L "cat debian/rules"

