#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                                        ============
# @ ${SOURCE_PATH}
L "fgrep -v '[ja]=' data/hello.desktop > data/hello.desktop.in"
L "rm data/hello.desktop"
L "cat data/hello.desktop.in"
