#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                                        ==============
# @ ${SOURCE_PATH}
# Let's pretend to add debian/source/local-options in source interactively
echo "[${SOURCE_DIR}] \$ mv debian/source/options.ex debian/source/options"
echo "[${SOURCE_DIR}] \$ vim debian/source/options"
echo " ... hack, hack, hack, ..."
# Let's set debian/source/options non-interactively
rm -f debian/source/options.ex
cp -f ${EXAMPLES_PATH}/${PROJECT}/debian/source/options debian/source/options
L "cat debian/source/options"
