#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                       <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
# @ ${SOURCE_PATH}
CD ${BASE_PATH} >/dev/null
cd ${BASE_PATH}
L "tar --xz -cf ${PROJECT}.${TARZ} ${PROJECT}"
L "tree"
