#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                       =============
# @ ${BASE_PATH}

for deb in $(ls *.deb); do
# keep it within 80-chars
echo "[${SOURCE_DIR}] \$ dpkg -f ${deb} pre-depends \\"
echo "            depends recommends conflicts breaks"
dpkg -f ${deb} pre-depends depends recommends conflicts breaks
done
