#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                       ============
# @ ${BASE_PATH}
L "cat ${PROJECT}/po/LINGUAS"
L "cat ${PROJECT}/po/POTFILES.in"

