#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                                        ============
# @ ${SOURCE_PATH}
echo "[${SOURCE_DIR}] $ vim configure.ac"
echo " ... hack, hack, hack, ..."
cp -f ../../../debhello-3.3/configure.ac configure.ac
L "cat configure.ac"

