#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                                         =============
# @ ${SOURCE_PATH}
echo "[${SOURCE_DIR}] \$ vim debian/install"
echo " ... hack, hack, hack, ..."
cp -f ${EXAMPLES_PATH}/${PROJECT}/debian/install debian/install
L "cat debian/install"

