#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                                        ==============
# @ ${SOURCE_PATH}
echo "[${SOURCE_DIR}] \$ vim debian/control"
echo " ... hack, hack, hack, ..."
cp -f ${EXAMPLES_PATH}/${PROJECT}/debian/control debian/control
L "cat debian/control"

