# directory structure (abs path)
#
# @ ${EXAMPLES_PATH}           examples/
# + - @ ${BUILD_PATH}          examples/debhello-*.*_build-*
#     +- @ ${BASE_PATH}        examples/debhello-*.*_build-*/base_dir
#                              examples/debhello-*.*_build-*/base_dir/debhello-*.*.tar.xz (tar)<F3>
#        +- @ ${SOURCE_PATH}   examples/debhello-*.*_build-*/base_dir/debhello-*.* (dir)

#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                      >>>>>>>>>>>>>>>>>>>>>>>>>>>>>


echo "[base_dir] \$ wget http://www.example.org/download/${PROJECT}.tar.xz"
echo " ..."
# Reality behind scene
cp -a ${EXAMPLES_PATH}/${PROJECT}.${TARZ} ${BASE_PATH}
CD ${BASE_PATH} >/dev/null
cd ${BASE_PATH}
L "tar --xz -xmf ${PROJECT}.tar.xz"
L "tree"
