#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                                        ==============
# @ ${SOURCE_PATH}
echo " ... hack, hack, hack, ..."
cp -f ${EXAMPLES_PATH}/${PROJECT}/debian/libsharedlib1.symbols debian/libsharedlib1.symbols
L "cat debian/libsharedlib1.symbols"

