# Fake download session
echo " \$ wget http://www.example.org/download/${PROJECT}.tar.xz"
echo " ..."
# Reality behind scene
cp -a ${EXAMPLES_PATH}/${PROJECT}.${TARZ} ${BUILD_PATH}
CD ${BUILD_PATH} >/dev/null
cd ${BUILD_PATH}
L "tar --xz -xmf ${PROJECT}.tar.xz"
L "tree"
