#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                       =============
# @ ${BASE_PATH}

realpath "$(command -v debmake)" | sed -e "s,/home/$(id -un),~,"
