#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                                        ==============
# @ ${SOURCE_PATH}
L "rm -f debian/clean debian/dirs debian/install debian/links"
L "rm -f debian/README.source debian/source/*.ex"
echo " ... hack, hack, hack, ..."
L "tree -F debian"
