#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                       =============
# @ ${BASE_PATH}
for deb in $(ls *.deb); do
L "dpkg -c ${deb}" | sed -e 's/root.root...............-..-.. ..:../root\/root ... /'
done
