#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                       =============
# @ ${BASE_PATH}

L "cat debian/patches/series"
L "cat debian/patches/debian-changes"
