#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                       >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
CD ${SOURCE_PATH}
cd ${SOURCE_PATH}
echo "[${SOURCE_DIR}] \$ vim debian/rules"
echo " ... hack, hack, hack, ..."
cp -f ${EXAMPLES_PATH}/${PROJECT}/debian/rules debian/rules
L "cat debian/rules"

