#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                                        =============
# @ ${SOURCE_PATH}
L "rm -f debian/clean debian/dirs debian/links"
L "rm -f debian/README.source debian/source/*.ex"
L "rm -rf debian/patches"
L "tree -F debian"
