# directory structure (abs path)
#
# @ ${EXAMPLES_PATH}
# + - @ ${BUILD_PATH}
#     +- @ ${BASE_PATH}
#        +- @ ${SOURCE_PATH}

#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                      >>>>>>>>>>>>>>>>>>>>>>>>>>>>>
CD ${BASE_PATH} >/dev/null
cd ${BASE_PATH}
L "mkdir ${PROJECT}"
L "tree"
