#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                                        ============
# @ ${SOURCE_PATH}
L "xgettext -f po/POTFILES.in -d debhello -o po/debhello.pot -k_"
L "cat po/debhello.pot"
