# Debianize (initial)
#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                        >>>>>>>>>>>>>>>>>>>>>>>>>>>>>
CD ${SOURCE_PATH}
cd ${SOURCE_PATH}
L "debmake -p debhello -x3 -t -T -u 0.1 -r 1"
