#  ${EXAMPLES_PATH} >> ${BUILD_PATH} >> ${BASE_PATH}  >> ${SOURCE_PATH}
#                                       ============
# @ ${BASE_PATH}
L "cat ${PROJECT}/Makefile.am"
L "cat ${PROJECT}/man/Makefile.am"
L "cat ${PROJECT}/lib/Makefile.am"
L "cat ${PROJECT}/src/Makefile.am"

